summaryrefslogtreecommitdiffstats
path: root/kalarm/lib/dateedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kalarm/lib/dateedit.h')
-rw-r--r--kalarm/lib/dateedit.h15
1 files changed, 8 insertions, 7 deletions
diff --git a/kalarm/lib/dateedit.h b/kalarm/lib/dateedit.h
index 7ea09e01b..7ad0a7a05 100644
--- a/kalarm/lib/dateedit.h
+++ b/kalarm/lib/dateedit.h
@@ -37,13 +37,14 @@
class DateEdit : public KDateEdit
{
Q_OBJECT
+ TQ_OBJECT
public:
/** Constructor.
* @param parent The parent object of this widget.
* @param name The name of this widget.
*/
- explicit DateEdit(TQWidget* parent = 0, const char* name = 0);
- /** Returns true if the widget tqcontains a valid date. */
+ explicit DateEdit(TQWidget* tqparent = 0, const char* name = 0);
+ /** Returns true if the widget contains a valid date. */
bool isValid() const { return date().isValid(); }
/** Returns the earliest date which can be entered.
* If there is no minimum date, returns an invalid date.
@@ -56,15 +57,15 @@ class DateEdit : public KDateEdit
/** Sets the earliest date which can be entered.
* @param date Earliest date allowed. If invalid, any minimum limit is removed.
* @param errorDate Error message to be displayed when a date earlier than
- * @p date is entered. Set to TQString::null to use the default error message.
+ * @p date is entered. Set to TQString() to use the default error message.
*/
- void setMinDate(const TQDate& date, const TQString& errorDate = TQString::null);
+ void setMinDate(const TQDate& date, const TQString& errorDate = TQString());
/** Sets the latest date which can be entered.
* @param date Latest date allowed. If invalid, any maximum limit is removed.
* @param errorDate Error message to be displayed when a date later than
- * @p date is entered. Set to TQString::null to use the default error message.
+ * @p date is entered. Set to TQString() to use the default error message.
*/
- void setMaxDate(const TQDate& date, const TQString& errorDate = TQString::null);
+ void setMaxDate(const TQDate& date, const TQString& errorDate = TQString());
/** Sets the date held in the widget to an invalid date. */
void setInvalid();
@@ -37,13 +37,14 @@
public:
/** Constructor.
- * @param parent The parent object of this widget.
+ * @param tqparent The tqparent object of this widget.
* @param name The name of this widget.
*/